<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="125"/>
        <source>MX Package Installer</source>
        <translation>MX Installa Programmi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Applicazioni Popolari</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Package</source>
        <translation>Pacchetto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="468"/>
        <location filename="../mainwindow.ui" line="660"/>
        <location filename="../mainwindow.ui" line="1030"/>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Gestisci pacchetti popolari&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="730"/>
        <location filename="../mainwindow.ui" line="1055"/>
        <location filename="../mainwindow.ui" line="1274"/>
        <source>search</source>
        <translation>cerca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="772"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <location filename="../mainwindow.ui" line="1245"/>
        <source>= Installed packages</source>
        <translation>= Pacchetti installati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Enabled Repos</source>
        <translation>Repo abilitati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Remove orphan packages</source>
        <translation>Rimuovi i pacchetti orfani</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <location filename="../mainwindow.ui" line="1337"/>
        <source>Upgrade All</source>
        <translation>Aggiorna tutto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.ui" line="558"/>
        <location filename="../mainwindow.ui" line="886"/>
        <source>Installed:</source>
        <translation>Installati:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <location filename="../mainwindow.ui" line="508"/>
        <location filename="../mainwindow.ui" line="907"/>
        <source>Total packages:</source>
        <translation>Pacchetti Totali:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <location filename="../mainwindow.ui" line="615"/>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>Installa anche i Pacchetti &quot;Raccomandati&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <location filename="../mainwindow.ui" line="588"/>
        <location filename="../mainwindow.ui" line="879"/>
        <source>Upgradable:</source>
        <translation>Aggiornabili:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <location filename="../mainwindow.ui" line="522"/>
        <location filename="../mainwindow.ui" line="914"/>
        <source>Hide library and developer packages</source>
        <translation>Nascondi i pacchetti delle librerie e di sviluppo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <location filename="../mainwindow.ui" line="544"/>
        <location filename="../mainwindow.ui" line="966"/>
        <source>Refresh list</source>
        <translation>Ricarica elenco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <location filename="../mainwindow.ui" line="688"/>
        <location filename="../mainwindow.ui" line="1085"/>
        <location filename="../mainwindow.ui" line="1197"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtra i pacchetti secondo il loro stato.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <location filename="../mainwindow.ui" line="397"/>
        <location filename="../mainwindow.ui" line="691"/>
        <location filename="../mainwindow.ui" line="695"/>
        <location filename="../mainwindow.ui" line="1088"/>
        <location filename="../mainwindow.ui" line="1092"/>
        <location filename="../mainwindow.cpp" line="2645"/>
        <source>All packages</source>
        <translation>Tutti i pacchetti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="402"/>
        <location filename="../mainwindow.ui" line="700"/>
        <location filename="../mainwindow.ui" line="1097"/>
        <location filename="../mainwindow.cpp" line="2657"/>
        <source>Installed</source>
        <translation>Installati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <location filename="../mainwindow.ui" line="705"/>
        <location filename="../mainwindow.ui" line="1102"/>
        <location filename="../mainwindow.cpp" line="2656"/>
        <source>Upgradable</source>
        <translation>Aggiornabili</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="412"/>
        <location filename="../mainwindow.ui" line="710"/>
        <location filename="../mainwindow.ui" line="1107"/>
        <location filename="../mainwindow.ui" line="1234"/>
        <location filename="../mainwindow.cpp" line="2625"/>
        <location filename="../mainwindow.cpp" line="2658"/>
        <location filename="../mainwindow.cpp" line="2773"/>
        <location filename="../mainwindow.cpp" line="2774"/>
        <source>Not installed</source>
        <translation>Non installati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <location filename="../mainwindow.ui" line="752"/>
        <location filename="../mainwindow.ui" line="814"/>
        <source>= Upgradable package. Newer version available in selected repository.</source>
        <translation>= Pacchetto aggiornabile. Una versione più nuova è disponibile nel repository selezionato.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <location filename="../mainwindow.ui" line="650"/>
        <location filename="../mainwindow.ui" line="1020"/>
        <source>Package Name</source>
        <translation>Nome Pacchetto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <location filename="../mainwindow.ui" line="655"/>
        <location filename="../mainwindow.ui" line="1025"/>
        <location filename="../mainwindow.ui" line="1469"/>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>MX Test Repo</source>
        <translation>Repo MX Test</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="796"/>
        <source>Debian Backports</source>
        <translation>Debian Backports</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1142"/>
        <source>Flatpaks</source>
        <translation>Pacchetti Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1148"/>
        <location filename="../mainwindow.ui" line="1152"/>
        <source>For all users</source>
        <translation>Per tutti gli utenti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1157"/>
        <source>For current user</source>
        <translation>Per l&apos;utente corrente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1165"/>
        <source>Remote (repo):</source>
        <translation>Remote (repo):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1200"/>
        <location filename="../mainwindow.ui" line="1204"/>
        <location filename="../mainwindow.cpp" line="2605"/>
        <source>All apps</source>
        <translation>Tutte le app.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.cpp" line="2610"/>
        <source>All runtimes</source>
        <translation>Tutti i runtime</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1214"/>
        <location filename="../mainwindow.cpp" line="2615"/>
        <source>All available</source>
        <translation>Tutte le app disponibili</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1219"/>
        <location filename="../mainwindow.cpp" line="2603"/>
        <source>Installed apps</source>
        <translation>App. installate</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1224"/>
        <location filename="../mainwindow.cpp" line="2601"/>
        <source>Installed runtimes</source>
        <translation>Runtime installati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1229"/>
        <location filename="../mainwindow.cpp" line="2623"/>
        <location filename="../mainwindow.cpp" line="2766"/>
        <location filename="../mainwindow.cpp" line="2767"/>
        <source>All installed</source>
        <translation>Tutti i pacchetti installati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1316"/>
        <source>Total items </source>
        <translation>N.° totale voci</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1330"/>
        <source>Installed apps:</source>
        <translation>App. installate:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1383"/>
        <source>Advanced</source>
        <translation>Avanzate</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1413"/>
        <source>Total installed size:</source>
        <translation>Dimensione tot. degli installati:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1427"/>
        <source>Remove unused runtimes</source>
        <translation>Rimuovi i runtime inutilizzati</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1459"/>
        <source>Short Name</source>
        <translation>Nome abbreviato</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1464"/>
        <source>Full Package Name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1474"/>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1504"/>
        <location filename="../mainwindow.cpp" line="2390"/>
        <location filename="../mainwindow.cpp" line="2554"/>
        <source>Console Output</source>
        <translation>Output del Terminale</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1510"/>
        <source>Enter</source>
        <translation>Invio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1521"/>
        <source>Respond here, or just press Enter</source>
        <translation>Rispondi qui, o premi Invio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1580"/>
        <location filename="../mainwindow.cpp" line="1101"/>
        <location filename="../mainwindow.cpp" line="2760"/>
        <location filename="../mainwindow.cpp" line="2763"/>
        <location filename="../mainwindow.cpp" line="3028"/>
        <source>Install</source>
        <translation>Installa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1587"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1606"/>
        <source>Quit application</source>
        <translation> Chiudi l&apos;applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1609"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1616"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1648"/>
        <source>About this application</source>
        <translation>Informazioni su questa applicazione</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>About...</source>
        <translation>Info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1696"/>
        <source>Display help </source>
        <translation>Visualizza la guida</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1699"/>
        <source>Help</source>
        <translation>Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1706"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1722"/>
        <source>Uninstall</source>
        <translation>Disinstalla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1729"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="112"/>
        <source>Flatpak tab is disabled on 32-bit.</source>
        <translation>La scheda Flatpak è disabilitata in 32 bit.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Could not find MX sources.</source>
        <translation>Impossibile trovare le fonti di MX.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>Uninstalling packages...</source>
        <translation>Disinstallazione in corso dei pacchetti..</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>Running pre-uninstall operations...</source>
        <translation>Operazioni pre-disinstallazione in esecuzione...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="201"/>
        <source>Running post-uninstall operations...</source>
        <translation>Sto eseguendo operazioni post-installazione...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="218"/>
        <source>Refreshing sources...</source>
        <translation>Aggiornamento delle sorgenti...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <location filename="../mainwindow.cpp" line="1149"/>
        <location filename="../mainwindow.cpp" line="1278"/>
        <location filename="../mainwindow.cpp" line="1430"/>
        <location filename="../mainwindow.cpp" line="1493"/>
        <location filename="../mainwindow.cpp" line="1805"/>
        <location filename="../mainwindow.cpp" line="1929"/>
        <location filename="../mainwindow.cpp" line="2243"/>
        <location filename="../mainwindow.cpp" line="2255"/>
        <location filename="../mainwindow.cpp" line="2366"/>
        <location filename="../mainwindow.cpp" line="2382"/>
        <location filename="../mainwindow.cpp" line="2439"/>
        <location filename="../mainwindow.cpp" line="2467"/>
        <location filename="../mainwindow.cpp" line="2487"/>
        <location filename="../mainwindow.cpp" line="2851"/>
        <location filename="../mainwindow.cpp" line="2925"/>
        <location filename="../mainwindow.cpp" line="2955"/>
        <location filename="../mainwindow.cpp" line="3050"/>
        <location filename="../mainwindow.cpp" line="3071"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="233"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Si è verificato un problema durante l&apos;aggiornamento delle sorgenti. Alcune di queste potrebbero non aver fornito aggiornamenti. Per maggiori informazioni controlla:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="627"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Please wait...</source>
        <translation>Attendi...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="826"/>
        <location filename="../mainwindow.cpp" line="846"/>
        <source>Version </source>
        <translation>Versione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="827"/>
        <source> in the enabled repos</source>
        <translation>nei repo abilitati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Not available in the enabled repos</source>
        <translation>Non disponibile nei repo abilitati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source>Latest version </source>
        <translation>Ultima versione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="839"/>
        <source> already installed</source>
        <translation>già installato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="846"/>
        <source> installed</source>
        <translation>installato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="974"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Stai per utilizzare il repository MX Test, i cui pacchetti sono forniti a solo scopo di test. È possibile che possano danneggiare il sistema, quindi è consigliabile eseguire il backup del sistema e installare o aggiornare solo un pacchetto alla volta. Si prega di fornire un feedback nel forum in modo che il pacchetto possa essere valutato prima di inserirlo nel repo Main.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="983"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Stai per usare Debian Backports, che contiene pacchetti presi dalla release di Debian più nuova (chiamata &apos;testing&apos;), adattati e ricompilati per poter essere usati su Debian stabile. Non possono essere stati testati cosi ampiamente come nelle versioni stabili di Debian e MX Linux, e sono forniti così come li hanno pensati in Debian Test, con il rischio di incompatibilità con altri componenti di Debian Stable. Usa questo repository con cautela!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="991"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux include il repository di flatpaks solo per comodità dell&apos;utente e non è responsabile della funzionalità dei singoli flatpak. Per ulteriori informazioni consulta, nel Wiki, l&apos;argomento flatpaks.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="999"/>
        <location filename="../mainwindow.cpp" line="3059"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1003"/>
        <source>Do not show this message again</source>
        <translation>Non mostrare più questo messaggio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1098"/>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1114"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>I seguenti pacchetti sono stati selezionati. Clicca su Mostra Dettagli per l&apos;elenco delle modifiche</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1150"/>
        <location filename="../mainwindow.cpp" line="1279"/>
        <location filename="../mainwindow.cpp" line="1494"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Internet non è disponibile, non si riesce a scaricare l&apos;elenco dei pacchetti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1153"/>
        <source>Installing packages...</source>
        <translation>Installazione pacchetti in corso..</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1208"/>
        <source>Post-processing...</source>
        <translation>Post-processo in corso...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1240"/>
        <source>Pre-processing for </source>
        <translation>Pre-processo per</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1255"/>
        <source>Installing </source>
        <translation>Installazione in corso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1262"/>
        <source>Post-processing for </source>
        <translation>Post-processo per</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1431"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Si è verificato un errore nella scrittura del file 1%. Controlla di avere abbastanza spazio su disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1502"/>
        <source>Downloading package info...</source>
        <translation>Scaricamento informazioni pacchetto in corso..</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1806"/>
        <location filename="../mainwindow.cpp" line="1930"/>
        <source>dpkg command returned an error, please run &apos;dpkg --list&apos; in terminal and check the output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2005"/>
        <location filename="../mainwindow.cpp" line="2087"/>
        <location filename="../mainwindow.cpp" line="2110"/>
        <source>Package info</source>
        <translation>Info Pacchetto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2017"/>
        <location filename="../mainwindow.cpp" line="2992"/>
        <source>More &amp;info...</source>
        <translation>Altro &amp; info...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2048"/>
        <source>Packages to be installed: </source>
        <translation>Pacchetti da installare:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2227"/>
        <location filename="../mainwindow.cpp" line="2239"/>
        <location filename="../mainwindow.cpp" line="2252"/>
        <location filename="../mainwindow.cpp" line="2341"/>
        <location filename="../mainwindow.cpp" line="2363"/>
        <location filename="../mainwindow.cpp" line="2848"/>
        <location filename="../mainwindow.cpp" line="2921"/>
        <location filename="../mainwindow.cpp" line="2949"/>
        <location filename="../mainwindow.cpp" line="3046"/>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2227"/>
        <location filename="../mainwindow.cpp" line="2239"/>
        <location filename="../mainwindow.cpp" line="2252"/>
        <location filename="../mainwindow.cpp" line="2341"/>
        <location filename="../mainwindow.cpp" line="2363"/>
        <location filename="../mainwindow.cpp" line="2379"/>
        <location filename="../mainwindow.cpp" line="2848"/>
        <location filename="../mainwindow.cpp" line="2921"/>
        <location filename="../mainwindow.cpp" line="2949"/>
        <location filename="../mainwindow.cpp" line="3046"/>
        <location filename="../mainwindow.cpp" line="3068"/>
        <source>Processing finished successfully.</source>
        <translation>L&apos;elaborazione è terminata correttamente.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2244"/>
        <location filename="../mainwindow.cpp" line="2256"/>
        <location filename="../mainwindow.cpp" line="2852"/>
        <location filename="../mainwindow.cpp" line="2926"/>
        <location filename="../mainwindow.cpp" line="2956"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>È stato rilevato un problema durante l&apos;installazione, controlla l&apos;output del terminale.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2266"/>
        <source>About %1</source>
        <translation>Circa %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2267"/>
        <source>Version: </source>
        <translation>Versione:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2269"/>
        <source>Package Installer for MX Linux</source>
        <translation>Programma di installazione pacchetti per MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2271"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2272"/>
        <source>%1 License</source>
        <translation>%1 Licenza</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2284"/>
        <source>%1 Help</source>
        <translation>%1 Aiuto</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2366"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Si è verificato un problema nella disinstallazione, controlla l&apos;output</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2379"/>
        <location filename="../mainwindow.cpp" line="3068"/>
        <source>Success</source>
        <translation>Successo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2382"/>
        <location filename="../mainwindow.cpp" line="3071"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>È stato riscontrato un problema durante la disinstallazione del programma</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2440"/>
        <location filename="../mainwindow.cpp" line="2468"/>
        <location filename="../mainwindow.cpp" line="2488"/>
        <source>Could not download the list of packages. Please check your APT sources.</source>
        <translation>Impossibile scaricare l&apos;elenco dei pacchetti. Controlla le tue fonti APT.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2520"/>
        <location filename="../mainwindow.cpp" line="2536"/>
        <source>Flatpak not installed</source>
        <translation>Il flatpak non è stato installato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2521"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Il flatpak al momento non è installato.
OK per procedere ad installarlo?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2536"/>
        <source>Flatpak was not installed</source>
        <translation>Il flatpak non è stato installato</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2558"/>
        <source>Needs re-login</source>
        <translation>E&apos; necessario rieseguire il Login</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2559"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Potrebbe essere necessario uscire dalla sessione e rieseguire il login per vedere le voci installate nel menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2760"/>
        <source>Upgrade</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2880"/>
        <source>Quit?</source>
        <translation>Esci?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2881"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Il processo è ancora in corso, uscire ora potrebbe lasciare il sistema in uno stato instabile.&lt;p&gt;&lt;b&gt;Sei sicuro di voler uscire da MX Installa Programmi?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3026"/>
        <source>Reinstall</source>
        <translation>Reinstalla</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3051"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>Problema riscontrato durante l&apos;ultima operazine, controlla l&apos;output della console.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3060"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>Operazioni potenzialmente pericolose.
Assicurati di controllare attentamente l&apos;elenco dei pacchetti da rimuovere.</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="13"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Gestisci i remotes (repo) dei flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="22"/>
        <source>For all users</source>
        <translation>Per tutti gli utenti</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For current user</source>
        <translation>Per l&apos;utente corrente</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="29"/>
        <source>enter Flatpak remote URL</source>
        <translation>inserisci l&apos;URL del Flatpak remote</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="32"/>
        <source>enter Flatpakref location to install app</source>
        <translation>inserisci la localizzazione di Flatpakref per installare app</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="34"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Aggiungi o rimuovi remotes (repos) di flatpak, oppure installa apps usando l&apos;URL flatpakref o il percorso di localizzazione</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="43"/>
        <source>Remove remote</source>
        <translation>Rimuovi remote</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="48"/>
        <source>Add remote</source>
        <translation>Aggiungi remote</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="53"/>
        <source>Install app</source>
        <translation>Installa app</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="58"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="75"/>
        <source>Not removable</source>
        <translation>Non rimovibile</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="76"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub è il principale remote di Flatpak e non verrà rimosso</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="95"/>
        <source>Error adding remote</source>
        <translation>E&apos; incorso un errore nell&apos;aggiungere il remote</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="96"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Non si riesce ad aggiugere il remote - il comando ha restituito un errore. Ricontrolla l&apos;indirizzo del remote e prova di nuovo</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Success</source>
        <translation>Operazione riuscita</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Remote added successfully</source>
        <translation>Il remote è stato aggiunto con successo</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="71"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <location filename="../about.cpp" line="82"/>
        <source>Changelog</source>
        <translation>Registro delle modifiche</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="50"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="51"/>
        <source>Dpkg/apt database is locked by another program: %1
Close the program, or wait until it is done processing and try again.</source>
        <translation>Il database Dpkg/apt è bloccato da un altro programma: %1
Chiudi il programma o attendi il completamento dell&apos;elaborazione e riprova.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>MX Package Installer is a tool used for managing packages on MX Linux
    - installs popular programs from different sources
    - installs programs from the MX Test repo
    - installs programs from Debian Backports repo
    - installs flatpaks</source>
        <translation>MX Installa Programmi è uno strumento usato per gestire i pacchetti su MX Linux
    - installa programmi popolari da fonti differenti
    - installa programmi dal repo MX Test
    - installa programmi dal repo Debian Backports
    - installa flatpaks</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Skip online check if it falsely reports lack of internet access.</source>
        <translation>Salta il controllo online se segnala erroneamente la mancanza di accesso a Internet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="95"/>
        <location filename="../main.cpp" line="103"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sembra che tu sia loggato come root, fai il log out e poi il log in come utente normale per usare questo programma.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <source>You must run this program with admin access.</source>
        <translation>Devi eseguire questo programma come amministratore.</translation>
    </message>
</context>
</TS>
